@@ -243,6 +243,9 @@ regress=function(formula, data, family=NULL,
 #' Not applicable to generalized linear (mixed) models.
 #' @param digits,nsmall Number of decimal places of output. Default is \code{3}.
 #' @param file File name of MS Word (\code{.doc}).
+#' @param check If there is only one model in \code{model.list}, it checks for multicollinearity
+#' using \code{\link[performance:check_collinearity]{performance::check_collinearity()}}.
+#' You may turn it off by setting \code{check=FALSE}.
 #' @param zero Display "0" before "."? Default is \code{TRUE}.
 #' @param modify.se Replace standard errors.
 #' Useful if you need to replace raw SEs with robust SEs.
@@ -330,6 +333,7 @@ model_summary=function(model.list,
                        digits=3,
                        nsmall=digits,
                        file=NULL,
+                       check=TRUE,
                        zero=ifelse(std, FALSE, TRUE),
                        modify.se=NULL,
                        modify.head=NULL,
@@ -476,13 +480,13 @@ model_summary=function(model.list,
     cat(output)
     Print("<<italic Note>>. * <<italic p>> < .05, ** <<italic p>> < .01, *** <<italic p>> < .001.")
     cat("\n")
-    if(length(model.list)==1) {
+    if(length(model.list)==1 & check==TRUE) {
       try({
         suppressWarnings({
-          check=performance::check_collinearity(model.list[[1]])
+          check.coll=performance::check_collinearity(model.list[[1]])
         })
-        if(!is.null(check)) {
-          print(check)
+        if(!is.null(check.coll)) {
+          print(check.coll)
           cat("\n")
         }
       }, silent=TRUE)
@@ -857,15 +861,15 @@ HLM_ICC=function(model, nsmall=3) {
 #' @references
 #' Hox, J. J. (2010).
 #' \emph{Multilevel analysis: Techniques and applications} (2nd ed.).
-#' New York, NY: Routledge. \doi{10.4324/9780203852279}
+#' New York, NY: Routledge.
 #'
 #' Nakagawa, S., & Schielzeth, H. (2013).
 #' A general and simple method for obtaining \emph{R}^2 from generalized linear mixed-effects models.
-#' \emph{Methods in Ecology and Evolution, 4,} 133-142. \doi{10.1111/j.2041-210x.2012.00261.x}
+#' \emph{Methods in Ecology and Evolution, 4,} 133-142.
 #'
 #' Xu, R. (2003).
 #' Measuring explained variation in linear mixed effects models.
-#' \emph{Statistics in Medicine, 22,} 3527-3541. \doi{10.1002/sim.1572}
+#' \emph{Statistics in Medicine, 22,} 3527-3541.
 #'
 #' @seealso
 #' \code{\link{print_table}} (print simple table)
