@@ -21,7 +21,8 @@ interaction_F_test=function(model, data=NULL, data.name="data") {
     row.names(aov.table)=c(gsub(":", " x ", row.names(dp1)),
                            "(All Interactions)")
   } else {
-    dp1=drop1(model, scope=interms, test="F")
+    # dp1=drop1(model, scope=interms, test="F")
+    dp1=anova(model)[interms,]
     aov.table=data.frame(
       `F`=dp1[,"F value"],
       df1=dp1[,"NumDF"],
@@ -256,7 +257,7 @@ boot_ci=function(boot,
 #' and \href{https://www.processmacro.org/download.html}{R script file "process.R"}
 #' (the official PROCESS R code by \emph{Andrew F. Hayes}, but it is not yet an R package and has some bugs and limitations).
 #'
-#' Here, the \strong{\code{\link[bruceR:PROCESS]{bruceR::PROCESS()}}} function provides
+#' Here, the \code{\link[bruceR:PROCESS]{bruceR::PROCESS()}} function provides
 #' an alternative to performing mediation/moderation analyses in R.
 #' This function supports a total of \strong{24} kinds of SPSS PROCESS models (Hayes, 2018)
 #' and also supports multilevel mediation/moderation analyses.
@@ -264,12 +265,26 @@ boot_ci=function(boot,
 #' moderated moderation (3-way interaction), and moderated mediation (conditional indirect effect) analyses
 #' for \strong{(generalized) linear or linear mixed models}.
 #'
-#' Specifically, the \strong{\code{\link[bruceR:PROCESS]{bruceR::PROCESS()}}} function
-#' first builds regression models according to the data, variable names, and a few other arguments
+#' Specifically, the \code{\link[bruceR:PROCESS]{bruceR::PROCESS()}} function
+#' builds regression models based on the data, variable names, and a few other arguments
 #' that users input (with \strong{no need to} specify the PROCESS model number and \strong{no need to} manually mean-center the variables).
-#' The function can automatically judge the model number/type and also automatically conduct mean-centering before model building.
+#' The function can automatically judge the model number/type and also conduct grand-mean centering before model building
+#' (using the \code{\link[bruceR:grand_mean_center]{bruceR::grand_mean_center()}} function).
 #'
-#' Then, it uses:
+#' Note that this automatic grand-mean centering
+#' (1) makes the results of main effects accurate for interpretation;
+#' (2) does not change any results of model fit (it only affects the interpretation of main effects);
+#' (3) is only conducted in "PART 1" (for an accurate estimate of main effects) but not in "PART 2" because
+#' it is more intuitive and interpretable to use the raw values of variables for the simple-slope tests in "PART 2";
+#' (4) is not optional to users because mean-centering should always be done when there is an interaction;
+#' (5) is not conflicted with group-mean centering because after group-mean centering the grand mean of a variable will also be 0,
+#' such that the automatic grand-mean centering (with mean = 0) will not change any values of the variable.
+#'
+#' If you need to do group-mean centering, please do this before using PROCESS.
+#' \code{\link[bruceR:group_mean_center]{bruceR::group_mean_center()}} is a useful function of group-mean centering.
+#' Remember that the automatic grand-mean centering in PROCESS never affects the values of a group-mean centered variable, which already has a grand mean of 0.
+#'
+#' The \code{\link[bruceR:PROCESS]{bruceR::PROCESS()}} function uses:
 #' \enumerate{
 #'   \item the \code{\link[interactions:sim_slopes]{interactions::sim_slopes()}} function to
 #'   estimate simple slopes (and conditional direct effects) in moderation, moderated moderation, and moderated mediation models
@@ -283,9 +298,12 @@ boot_ci=function(boot,
 #' the other R packages it uses internally (\code{mediation}, \code{interactions}, and/or \code{lavaan}).
 #'
 #' Two parts of results are printed:
-#' (1) \emph{regression model summary} (using \code{\link[bruceR:model_summary]{bruceR::model_summary()}} to summarize the models)
-#' and (2) \emph{mediation/moderation effect estimates} (using one or a combination of the above packages and functions to estimate the effects).
-#' To organize the Part 2 output, the results of \strong{Simple Slopes} are titled in \strong{green},
+#'
+#' PART 1. Regression model summary (using \code{\link[bruceR:model_summary]{bruceR::model_summary()}} to summarize the models)
+#'
+#' PART 2. Mediation/moderation effect estimates (using one or a combination of the above packages and functions to estimate the effects)
+#'
+#' To organize the PART 2 output, the results of \strong{Simple Slopes} are titled in \strong{green},
 #' whereas the results of \strong{Indirect Path} are titled in \strong{blue}.
 #'
 #' \strong{\emph{Disclaimer}:}
@@ -324,13 +342,14 @@ boot_ci=function(boot,
 #' @param covs Variable name(s) of covariate(s) (i.e., control variables).
 #' Use \code{c()} to combine multiple covariates.
 #' It supports all types of (and an infinite number of) variables.
-#' @param clusters HLM (multilevel) level-2 cluster(s):
-#' e.g., \code{"School_ID"} or \code{c("Sub", "Item")}.
+#' @param clusters HLM (multilevel) cluster(s):
+#' e.g., \code{"School"}, \code{c("Prov", "City")}, \code{c("Sub", "Item")}.
 #' @param hlm.re.m,hlm.re.y HLM (multilevel) random effect term of M model and Y model.
 #' By default, it converts \code{clusters} to \code{\link[lme4:lme4-package]{lme4}} syntax of random intercepts:
-#' e.g., \code{"(1 | School_ID)"} or \code{"(1 | Sub) + (1 | Item)"}.
-#' You can set these arguments to include more complex terms (e.g., random slopes).
-#' In most cases, no need to set these arguments.
+#' e.g., \code{"(1 | School)"} or \code{"(1 | Sub) + (1 | Item)"}.
+#'
+#' You may specify these arguments to include more complex terms:
+#' e.g., random slopes \code{"(X | School)"}, or 3-level random effects \code{"(1 | Prov/City)"}.
 #' @param hlm.type HLM (multilevel) mediation type (levels of "X-M-Y"):
 #' \code{"1-1-1"} (default),
 #' \code{"2-1-1"} (indeed the same as \code{"1-1-1"} in a mixed model),
@@ -838,19 +857,23 @@ PROCESS=function(data,
   clusters.text=varlist(clusters)
   Print("
   \n
-  <<bold ************ PART 1. Regression Model Summary ************>>
+  <<bold ****************** PART 1. Regression Model Summary ******************>>
 
   <<blue PROCESS Model Code : {pid}>> <<white (Hayes, 2018; <<underline www.guilford.com/p/hayes3>>)>>
   <<blue PROCESS Model Type : {ptype}>>
   <<green
-  -      Outcome (Y) : {y}
-  -    Predictor (X) : {x}{x.trans.info}
-  -    Mediators (M) : {meds.text}
-  -   Moderators (W) : {mods.text}
-  -   Covariates (C) : {covs.text}
-  - Level-2 Clusters : {clusters.text}
+  -    Outcome (Y) : {y}
+  -  Predictor (X) : {x}{x.trans.info}
+  -  Mediators (M) : {meds.text}
+  - Moderators (W) : {mods.text}
+  - Covariates (C) : {covs.text}
+  -   HLM Clusters : {clusters.text}
+  >>
+
+  <<yellow
+  All numeric predictors have been {ifelse(std, 'standardized', 'grand-mean centered')}.
+  (For details, please see the help page of PROCESS.)
   >>
-  <<yellow All numeric predictors have been {ifelse(std, 'standardized', 'mean-centered')}.>>
   \n
   ")
 
@@ -861,7 +884,13 @@ PROCESS=function(data,
   }
   Print("<<italic Formula of Outcome>>:")
   cat("-   ", fy)
-  cat("\n")
+  cat("\n
+CAUTION:
+  Fixed effect (coef.) of a predictor involved in an interaction
+  denotes its \"simple effect/slope\" when the other predictor = 0.
+  Only when all predictors in interaction have been mean-centered
+  can the fixed effect denote the \"main effect\"!
+  ")
 
   ## Regression Model Building
   if(Y01==FALSE) {
